SWDEV-554372 - Add 3 HIP_GET_PROC_ADDRESS_xxx flags (#1057)
此提交包含在:
@@ -85,6 +85,7 @@ THE SOFTWARE.
|
||||
|
||||
// Driver Entry Point API
|
||||
#define hipGetDriverEntryPoint __HIP_API_SPT(hipGetDriverEntryPoint)
|
||||
#define hipGetProcAddress __HIP_API_SPT(hipGetProcAddress)
|
||||
#endif
|
||||
|
||||
#ifdef __cplusplus
|
||||
@@ -197,6 +198,8 @@ hipError_t hipStreamGetCaptureInfo_v2_spt(hipStream_t stream,
|
||||
hipError_t hipLaunchHostFunc_spt(hipStream_t stream, hipHostFn_t fn, void* userData);
|
||||
hipError_t hipGetDriverEntryPoint_spt(const char* symbol, void** funcPtr, unsigned long long flags,
|
||||
hipDriverEntryPointQueryResult* status);
|
||||
hipError_t hipGetProcAddress_spt(const char* symbol, void** pfn, int hipVersion, uint64_t flags,
|
||||
hipDriverProcAddressQueryResult* symbolStatus);
|
||||
|
||||
|
||||
#ifdef __cplusplus
|
||||
|
||||
@@ -1111,6 +1111,8 @@ typedef hipError_t (*t_hipLibraryEnumerateKernels)(hipKernel_t* kernels, unsigne
|
||||
hipLibrary_t library);
|
||||
typedef hipError_t (*t_hipKernelGetLibrary)(hipLibrary_t* library, hipKernel_t kernel);
|
||||
typedef hipError_t (*t_hipKernelGetName)(const char** name, hipKernel_t kernel);
|
||||
typedef hipError_t (*t_hipGetProcAddress_spt)(const char* symbol, void** pfn, int hipVersion, uint64_t flags,
|
||||
hipDriverProcAddressQueryResult* symbolStatus);
|
||||
|
||||
// HIP Compiler dispatch table
|
||||
struct HipCompilerDispatchTable {
|
||||
@@ -1696,6 +1698,7 @@ struct HipDispatchTable {
|
||||
|
||||
// HIP_RUNTIME_API_TABLE_STEP_VERSION == 18
|
||||
t_hipOccupancyAvailableDynamicSMemPerBlock hipOccupancyAvailableDynamicSMemPerBlock_fn;
|
||||
t_hipGetProcAddress_spt hipGetProcAddress_spt_fn;
|
||||
|
||||
// DO NOT EDIT ABOVE!
|
||||
// HIP_RUNTIME_API_TABLE_STEP_VERSION == 19
|
||||
|
||||
新增問題並參考
封鎖使用者